# Hijri Dates

Provides Hijri calendar support for Drupal date fields and Views. Converts Gregorian dates to Hijri format with automatic language detection.

## Features

* Converts dates to Hijri calendar format
* Works with datetime, timestamp, and daterange fields
* Integrates with Views and field formatters
* Automatic language handling (Arabic/English)
* Customizable date correction for regional variations
* Twig filter and function for template usage

## Requirements

* Drupal 9 or 10
* ArPHP library (installed via Composer)

## Installation

```bash
composer require drupal/hijri_dates
drush en hijri_dates
```

## Usage

### Field Formatters & Views

1. Go to "Manage Display" of a content type or Views field settings
2. Click the gear icon next to a date field
3. Check "Use Hijri calendar"
4. Select date format and optional correction
5. Save settings

Works with all date-based fields including content dates, custom date fields, and date ranges.

### Date Correction

For regional moon sighting variations:
```
+1 day    # Common adjustment
-1 day    # Subtract one day
```

### Twig Usage

```twig
{{ node.created.value|hijri }}
{{ node.created.value|hijri('medium') }}
{{ node.created.value|hijri(null, '+1 day') }}
{{ hijri(node.created.value, 'medium', '+1 day') }}
```

### PHP Usage

```php
// Basic usage
$hijri_service = \Drupal::service('hijri_dates.service');
$hijri_date = $hijri_service->formatHijri($timestamp);

// With format and correction
$hijri_date = $hijri_service->formatHijri($timestamp, 'medium', '+1 day');

// With custom format
$hijri_date = $hijri_service->formatHijri($timestamp, '!Y/m/d');

// With DateTime objects
$date = new \DateTime('2023-05-15');
$hijri_date = $hijri_service->formatHijri($date);
```

## Format Support

Supports standard PHP date format patterns:

* `l, D` - Weekday names (full, short)
* `F, M` - Month names (full, short)
* `j, d` - Day of month (with/without leading zeros)
* `Y, y` - Year (4-digit, 2-digit)
* `H, h, i, s` - Time components

Incompatible: `S, T, e, I, O, P, Z, c, r, U` (timezone and special formats)

## Language Handling

* Arabic interface: Arabic month/day names and numerals (e.g., "٢٢ ذو الحجة ١٤٤٦")
* English interface: Transliterated names and Western numerals (e.g., "Dhu al-Hijjah 22, 1446")

## Credits

Uses the [ArPHP](https://github.com/khaled-alshamaa/ar-php) library by Khaled Al-Sham'aa.
